(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@rxweb/dom'), require('@rxweb/localization')) :
    typeof define === 'function' && define.amd ? define('@rxweb/js', ['exports', '@rxweb/dom', '@rxweb/localization'], factory) :
    (global = global || self, factory((global.rxweb = global.rxweb || {}, global.rxweb.js = {}), global['@rxweb/dom'], global['@rxweb/localization']));
}(this, function (exports, dom, localization) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    /* global Reflect, Promise */

    var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };

    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    var BaseDomProvider = /** @class */ (function () {
        function BaseDomProvider() {
            this.elements = {};
        }
        BaseDomProvider.prototype.createElement = function (parentElement, elementName, elementConfig, modelObject, index, customEvents) {
            var _this = this;
            var domManipulation = new dom.DomManipulation(parentElement, elementName, elementConfig, modelObject, index, customEvents);
            domManipulation.bind();
            this.elements[domManipulation.controlId] = domManipulation;
            if (elementConfig.sourceItems && elementConfig.childrens)
                elementConfig.sourceItems.forEach(function (t, index) {
                    var childrenLength = elementConfig.childrens.length;
                    _this.createChildElements(domManipulation.element, [childrenLength > index ? elementConfig.childrens[index] : elementConfig.childrens[0]], t, index, customEvents);
                });
            else if (elementConfig.childrens)
                this.createChildElements(domManipulation.element, elementConfig.childrens, modelObject, 0, customEvents);
            return domManipulation;
        };
        BaseDomProvider.prototype.createChildElements = function (element, childrens, modelObject, index, customEvents) {
            var _this = this;
            childrens.forEach(function (templateConfig) {
                Object.keys(templateConfig).forEach(function (t) {
                    var result = true;
                    if (templateConfig[t].if)
                        result = templateConfig[t].if.call(modelObject);
                    if (templateConfig[t].event && templateConfig[t].event.onclick)
                        if (customEvents[templateConfig[t].event.onclick])
                            templateConfig[t].event.onclick = customEvents[templateConfig[t].event.onclick];
                    if (result)
                        _this.createElement(element, t, templateConfig[t], modelObject, index, customEvents);
                });
            });
        };
        BaseDomProvider.prototype.removeChildren = function (element, isRemoveRoot) {
            if (isRemoveRoot === void 0) { isRemoveRoot = true; }
            if (element) {
                while (element.firstElementChild && element.firstElementChild.tagName.indexOf("-") === -1)
                    this.removeChildren(element.firstElementChild);
                if (isRemoveRoot) {
                    var controlId = element.getAttribute("data-rxwebid");
                    if (controlId && this.elements[controlId]) {
                        this.elements[controlId].destroy();
                        delete this.elements[controlId];
                    }
                }
            }
        };
        return BaseDomProvider;
    }());


    (function (DialogClick) {
        DialogClick[DialogClick["Ok"] = 1] = "Ok";
        DialogClick[DialogClick["Cancel"] = 2] = "Cancel";
        DialogClick[DialogClick["Save"] = 3] = "Save";
        DialogClick[DialogClick["DontSave"] = 4] = "DontSave";
    })(exports.DialogClick || (exports.DialogClick = {}));

    var DialogClass = /** @class */ (function () {
        function DialogClass() {
            this.root = [];
            this.nestedDiv = [];
            this.heading = [];
            this.paragraph = [];
        }
        return DialogClass;
    }());
    var DialogButtonClass = /** @class */ (function () {
        function DialogButtonClass() {
            this.ok = [];
            this.cancel = [];
            this.save = [];
            this.dontSave = [];
        }
        return DialogButtonClass;
    }());

    var OverlayDesign = /** @class */ (function () {
        function OverlayDesign() {
            this.class = [];
            this.style = {};
        }
        return OverlayDesign;
    }());


    (function (DialogViewMode) {
        DialogViewMode[DialogViewMode["onlyOk"] = 1] = "onlyOk";
        DialogViewMode[DialogViewMode["okWithCancel"] = 2] = "okWithCancel";
        DialogViewMode[DialogViewMode["saveAndDontSave"] = 3] = "saveAndDontSave";
    })(exports.DialogViewMode || (exports.DialogViewMode = {}));

    function getDefaultTemplate(dialogClass) {
        return {
            div: {
                class: dialogClass.root,
                style: dialogClass.rootStyle,
                childrens: [{
                        h2: {
                            class: dialogClass.heading, childrens: [{ text: { text: ":text.heading" } }]
                        },
                        p: { class: dialogClass.paragraph, childrens: [{ text: { text: ":text.message" } }] }
                    },
                    {
                        div: {
                            class: dialogClass.nestedDiv,
                            childrens: [{
                                    button: {
                                        if: function () { return this.viewMode == exports.DialogViewMode.onlyOk || this.viewMode == exports.DialogViewMode.okWithCancel; },
                                        class: dialogClass.button.ok,
                                        event: { click: 'ok' },
                                        childrens: [{ text: { text: ":text.ok" } }]
                                    }
                                },
                                {
                                    button: {
                                        if: function () { return this.viewMode == exports.DialogViewMode.saveAndDontSave; },
                                        event: { click: 'save' },
                                        class: dialogClass.button.save, childrens: [{ text: { text: ":text.save" } }]
                                    }
                                },
                                {
                                    button: {
                                        if: function () { return this.viewMode == exports.DialogViewMode.saveAndDontSave; },
                                        event: { click: 'dontsave' },
                                        class: dialogClass.button.dontSave, childrens: [{ text: { text: ":text.dontsave" } }]
                                    }
                                },
                                {
                                    button: {
                                        if: function () { return this.viewMode == exports.DialogViewMode.okWithCancel || this.viewMode == exports.DialogViewMode.saveAndDontSave; },
                                        event: { click: 'cancel' },
                                        class: dialogClass.button.cancel, childrens: [{ text: { text: ":text.cancel" } }]
                                    }
                                },
                            ]
                        }
                    }
                ]
            }
        };
    }

    var DialogConfig = /** @class */ (function () {
        function DialogConfig(message) {
            this.showIcon = false;
            this.text = new DialogTextConfig(message);
        }
        return DialogConfig;
    }());
    var DialogTextConfig = /** @class */ (function () {
        function DialogTextConfig(message) {
            this.ok = localization.MultiLingualData.get("global.dialog-ok");
            this.cancel = localization.MultiLingualData.get("global.dialog-cancel");
            this.save = localization.MultiLingualData.get("global.dialog-save");
            this.dontSave = localization.MultiLingualData.get("global.dialog-dontsave");
            this.heading = localization.MultiLingualData.get("global.dialog-heading");
            this.message = message.charAt(0) == ":" ? localization.MultiLingualData.get(message.replace(":", "")) : message;
        }
        return DialogTextConfig;
    }());

    var Dialog = /** @class */ (function (_super) {
        __extends(Dialog, _super);
        function Dialog() {
            var _this = _super.call(this) || this;
            _this.designClass = new DialogClass();
            _this.designClass.button = new DialogButtonClass();
            _this.defaultConfig = new DialogConfig("global.dialog-message");
            _this.designClass.overlay = new OverlayDesign();
            return _this;
        }
        Dialog.prototype.getDefaultTemplate = function () {
            return getDefaultTemplate(this.designClass);
        };
        Dialog.prototype.show = function (message, viewMode, template) {
            var _this = this;
            var promise = new Promise(function (resolve, reject) {
                var events = _this.getEvents(resolve);
                var template = template || _this.getDefaultTemplate();
                var data;
                if (message instanceof DialogConfig)
                    data = __assign({}, message, { viewMode: viewMode });
                else
                    data = __assign({}, _this.defaultConfig, { text: __assign({}, _this.defaultConfig.text, { message: message }) }, { viewMode: viewMode });
                if (_this.designClass.overlay.class || _this.designClass.overlay.style)
                    _this.overLayElement = _this.createElement(document.body, 'div', { class: _this.designClass.overlay.class, style: _this.designClass.overlay.style }, {}, 0, {});
                _this.domManipulation = _this.createElement(document.body, 'div', template.div, data, 0, { actions: events });
            });
            return promise;
        };
        Dialog.prototype.getEvents = function (resolve) {
            return { ok: function () { return resolve(exports.DialogClick.Ok); }, cancel: function () { return resolve(exports.DialogClick.Cancel); }, save: function () { return resolve(exports.DialogClick.Save); }, dontsave: function () { return resolve(exports.DialogClick.DontSave); } };
        };
        Dialog.prototype.hide = function () {
            this.removeChildren(this.overLayElement.element);
            this.removeChildren(this.domManipulation.element);
        };
        return Dialog;
    }(BaseDomProvider));

    var ModalClassConfig = /** @class */ (function () {
        function ModalClassConfig() {
            this.class = [];
            this.showIn = [];
            this.showOut = [];
            this.backDropClass = [];
            this.overlay = new OverlayDesign();
        }
        return ModalClassConfig;
    }());

    var Modal = /** @class */ (function (_super) {
        __extends(Modal, _super);
        function Modal() {
            var _this = _super.call(this) || this;
            _this.designClass = new ModalClassConfig();
            return _this;
        }
        Modal.prototype.getDefaultTemplate = function () {
            return {
                div: {
                    class: this.designClass.class,
                    style: this.designClass.style
                }
            };
        };
        Modal.prototype.show = function (component, params) {
            var _this = this;
            var promise = new Promise(function (resolve, reject) {
                if (_this.resolver) {
                    var template = _this.getDefaultTemplate();
                    var overLayElement = _this.createElement(document.body, "div", { class: _this.designClass.backDropClass }, {}, 0, {});
                    var domManipulation_1 = _this.createElement(document.body, "div", template.div, {}, 0, {});
                    var refResolver = {};
                    var componentRef = _this.resolver(component, __assign({}, params, { hide: _this.hideResolver(resolve, domManipulation_1, overLayElement, refResolver) }));
                    refResolver.destroy = componentRef.destroy;
                    domManipulation_1.element.appendChild(componentRef.element);
                    if (_this.designClass.showIn.length > 0)
                        setTimeout(function () {
                            domManipulation_1.addOrRemoveClass(_this.designClass.showIn);
                        }, 50);
                }
            });
            return promise;
        };
        Modal.prototype.hideResolver = function (resolve, domManipulation, overLayElement, refResolver) {
            var _this = this;
            return function (data) {
                _this.hide(resolve, data, domManipulation, overLayElement, refResolver);
            };
        };
        Modal.prototype.hide = function (resolve, data, domManipulation, overLayElement, refResolver) {
            var _this = this;
            if (this.designClass.showIn)
                domManipulation.addOrRemoveClass(this.designClass.showIn, false);
            setTimeout(function () {
                if (refResolver.destroy)
                    refResolver.destroy();
                _this.removeChildren(overLayElement.element);
                _this.removeChildren(domManipulation.element);
                resolve(data);
            }, 200);
        };
        return Modal;
    }(BaseDomProvider));

    var ToastrConfig = /** @class */ (function () {
        function ToastrConfig() {
            this.timeOut = 7000;
        }
        return ToastrConfig;
    }());
    var ToastrDesignClass = /** @class */ (function () {
        function ToastrDesignClass() {
            this.root = [];
            this.secondLevelDiv = [];
            this.thirdLevelDiv = [];
            this.showClass = [];
            this.hideClass = [];
        }
        return ToastrDesignClass;
    }());

    function getToastrTemplate(toastrDesign, config, hideConfig) {
        return {
            div: {
                class: toastrDesign.root,
                childrens: [{
                        div: {
                            class: toastrDesign.secondLevelDiv,
                            childrens: [{
                                    div: {
                                        class: toastrDesign.thirdLevelDiv,
                                        childrens: [
                                            {
                                                button: {
                                                    childrens: [{ text: { text: "x" } }],
                                                    class: ["toast-close-button", config && (config.autoHideDisable || config.enableCloseButton) ? "dummy" : "toast-close-display-none"],
                                                    event: {
                                                        click: function (event) {
                                                            if (config && (config.autoHideDisable || config.enableCloseButton) && hideConfig.domManipulation) {
                                                                hideConfig.hideFunc(hideConfig.domManipulation, hideConfig.toastrConfig);
                                                            }
                                                        }
                                                    }
                                                }
                                            },
                                            {
                                                text: { text: ":message" }
                                            }
                                        ]
                                    }
                                }]
                        }
                    }]
            }
        };
    }

    var Toastr = /** @class */ (function (_super) {
        __extends(Toastr, _super);
        function Toastr() {
            var _this = _super.call(this) || this;
            _this.designClass = new ToastrDesignClass();
            _this.defaultConfig = new ToastrConfig();
            _this.domManipulations = new Array();
            return _this;
        }
        Toastr.prototype.getDefaultTemplate = function (config, hideConfig) {
            return getToastrTemplate(this.designClass, config, hideConfig);
        };
        Toastr.prototype.getMessage = function (message) {
            return message.charAt(0) == ':' ? localization.MultiLingualData.get(message.replace(":", "")) : message;
        };
        Toastr.prototype.show = function (message, messageType, config, customTemplate) {
            message = this.getMessage(message);
            var hideConfig = { toastrConfig: toastrConfig, hideFunc: this.baseHide.bind(this) };
            var toastrConfig = config ? __assign({}, config, { messageType: messageType, message: message, timeOut: this.defaultConfig.timeOut }) : __assign({}, this.defaultConfig, { messageType: messageType, message: message });
            var template = customTemplate || this.getDefaultTemplate(config, hideConfig);
            this.createRoot();
            var domManipulation = this.createElement(this.rootElement.element, 'div', template.div, toastrConfig, 0, {});
            hideConfig.domManipulation = domManipulation;
            hideConfig.toastrConfig = toastrConfig;
            if (this.designClass.showClass)
                domManipulation.addOrRemoveClass(this.designClass.showClass);
            if (!config || (config && (!config.autoHideDisable && config.enableCloseButton)) || (config && (!config.autoHideDisable && !config.enableCloseButton)))
                this.hide(domManipulation, toastrConfig);
            this.domManipulations.push(domManipulation);
        };
        Toastr.prototype.createRoot = function () {
            if (!this.rootElement)
                this.rootElement = this.createElement(document.body, "div", {}, {}, 0, {});
        };
        Toastr.prototype.hide = function (domManipulation, toastrConfig) {
            var _this = this;
            setTimeout(function () {
                _this.baseHide(domManipulation, toastrConfig);
            }, toastrConfig.timeOut);
        };
        Toastr.prototype.baseHide = function (domManipulation, toastrConfig) {
            var _this = this;
            if (this.designClass.hideClass) {
                domManipulation.addOrRemoveClass(this.designClass.showClass, false);
                domManipulation.addOrRemoveClass(this.designClass.hideClass);
            }
            setTimeout(function () {
                if (_this.rootElement) {
                    _this.removeChildren(domManipulation.element);
                    var elements = _this.domManipulations.filter(function (t) { return t.element != null; });
                    if (elements.length == 0) {
                        _this.domManipulations = [];
                        _this.removeChildren(_this.rootElement.element);
                        _this.rootElement = null;
                    }
                }
            }, 50);
        };
        return Toastr;
    }(BaseDomProvider));


    (function (ToastrMessageType) {
        ToastrMessageType[ToastrMessageType["success"] = 1] = "success";
        ToastrMessageType[ToastrMessageType["error"] = 2] = "error";
        ToastrMessageType[ToastrMessageType["warning"] = 3] = "warning";
        ToastrMessageType[ToastrMessageType["info"] = 4] = "info";
    })(exports.ToastrMessageType || (exports.ToastrMessageType = {}));

    exports.Dialog = Dialog;
    exports.Modal = Modal;
    exports.Toastr = Toastr;
    exports.ɵa = BaseDomProvider;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=rxweb-js.umd.js.map
